isIdle property
bool
get
isIdle
True before the mutation has been called for the first time.
Implementation
bool get isIdle => !isMutating && !isSuccess && !isError;
True before the mutation has been called for the first time.
bool get isIdle => !isMutating && !isSuccess && !isError;