staleTime property
How long before cached data is considered stale and refetched in background. Defaults to Duration.zero — always refetch on mount.
Implementation
final Duration staleTime;
How long before cached data is considered stale and refetched in background. Defaults to Duration.zero — always refetch on mount.
final Duration staleTime;